nwbwidgets package
==================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   nwbwidgets.analysis
   nwbwidgets.controllers
   nwbwidgets.dashboards
   nwbwidgets.utils

Submodules
----------

nwbwidgets.allen module
-----------------------

.. automodule:: nwbwidgets.allen
   :members:
   :undoc-members:
   :show-inheritance:

nwbwidgets.base module
----------------------

.. automodule:: nwbwidgets.base
   :members:
   :undoc-members:
   :show-inheritance:

nwbwidgets.behavior module
--------------------------

.. automodule:: nwbwidgets.behavior
   :members:
   :undoc-members:
   :show-inheritance:

nwbwidgets.brains module
------------------------

.. automodule:: nwbwidgets.brains
   :members:
   :undoc-members:
   :show-inheritance:

nwbwidgets.dynamictablesummary module
-------------------------------------

.. automodule:: nwbwidgets.dynamictablesummary
   :members:
   :undoc-members:
   :show-inheritance:

nwbwidgets.ecephys module
-------------------------

.. automodule:: nwbwidgets.ecephys
   :members:
   :undoc-members:
   :show-inheritance:

nwbwidgets.ephys\_viz\_interface module
---------------------------------------

.. automodule:: nwbwidgets.ephys_viz_interface
   :members:
   :undoc-members:
   :show-inheritance:

nwbwidgets.file module
----------------------

.. automodule:: nwbwidgets.file
   :members:
   :undoc-members:
   :show-inheritance:

nwbwidgets.icephys module
-------------------------

.. automodule:: nwbwidgets.icephys
   :members:
   :undoc-members:
   :show-inheritance:

nwbwidgets.image module
-----------------------

.. automodule:: nwbwidgets.image
   :members:
   :undoc-members:
   :show-inheritance:

nwbwidgets.misc module
----------------------

.. automodule:: nwbwidgets.misc
   :members:
   :undoc-members:
   :show-inheritance:

nwbwidgets.ophys module
-----------------------

.. automodule:: nwbwidgets.ophys
   :members:
   :undoc-members:
   :show-inheritance:

nwbwidgets.panel module
-----------------------

.. automodule:: nwbwidgets.panel
   :members:
   :undoc-members:
   :show-inheritance:

nwbwidgets.spectrum module
--------------------------

.. automodule:: nwbwidgets.spectrum
   :members:
   :undoc-members:
   :show-inheritance:

nwbwidgets.timeseries module
----------------------------

.. automodule:: nwbwidgets.timeseries
   :members:
   :undoc-members:
   :show-inheritance:

nwbwidgets.version module
-------------------------

.. automodule:: nwbwidgets.version
   :members:
   :undoc-members:
   :show-inheritance:

nwbwidgets.view module
----------------------

.. automodule:: nwbwidgets.view
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: nwbwidgets
   :members:
   :undoc-members:
   :show-inheritance:
